import{d as t,o,Y as s,b as d,u as r,by as _,a0 as i}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9d729ab0-1273-4e4a-8ba4-ef83255bea31",e._sentryDebugIdIdentifier="sentry-dbid-9d729ab0-1273-4e4a-8ba4-ef83255bea31")}catch{}})();const c={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",c,[d(r(_))]))}});const p=i(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.1cbd28bb.js.map
