import{C as p}from"./controller.de82b471.js";import{d as i,ec as n,o as s,c as a,u as m}from"./index.97914b50.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.7bbb6df1.js";import"./gateway.f03e4b27.js";import"./popupNotifcation.f5d6fec9.js";import"./fetch.223a1647.js";import"./record.a76b6b89.js";import"./PhPencil.vue.19daefd9.js";import"./SaveButton.5c48e103.js";import"./UnsavedChangesHandler.e1b03d07.js";import"./ExclamationCircleOutlined.8d6633b2.js";import"./CrudView.87635648.js";import"./router.25b634fb.js";import"./Badge.d34a57fa.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.92667220.js";import"./BookOutlined.cfbaf67d.js";import"./url.9121ac6e.js";import"./PhDotsThreeVertical.vue.05e420b9.js";import"./index.dcf24033.js";import"./index.40a20e0a.js";import"./asyncComputed.d84da1aa.js";import"./polling.fe90557c.js";import"./index.19726194.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="19e2a62c-1480-49c6-af81-fbb6a8196bae",o._sentryDebugIdIdentifier="sentry-dbid-19e2a62c-1480-49c6-af81-fbb6a8196bae")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(f,d)=>(s(),a(c,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.16a10034.js.map
