import{_}from"./Login.vue_vue_type_script_setup_true_lang.f8324f0a.js";import{d as l,eF as m,ec as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.97914b50.js";import{u as h}from"./workspaceStore.6144f2aa.js";import"./Logo.6a7a7f34.js";import"./string.8b027234.js";import"./OTPInput.0427d908.js";import"./index.19726194.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0129bbf7-dbee-447f-b06d-23705f7f1af2",e._sentryDebugIdIdentifier="sentry-dbid-0129bbf7-dbee-447f-b06d-23705f7f1af2")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=b(),r=h(),f=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,u,p,i;return g(),y("div",v,[w(_,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=n(r).state.workspace)==null?void 0:u.brandName,locale:(i=(p=n(r).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:f},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.a6c9c03f.js.map
