import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.97914b50.js";import"./linters.188b2aea.js";import{W as s}from"./workspaces.a92903a0.js";import{C as d}from"./ContentLayout.d08fae26.js";import{a as f}from"./controller.de82b471.js";import{_ as u}from"./View.vue_vue_type_script_setup_true_lang.7bbb6df1.js";import"./asyncComputed.d84da1aa.js";import"./workspaceStore.6144f2aa.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";import"./record.a76b6b89.js";import"./gateway.f03e4b27.js";import"./popupNotifcation.f5d6fec9.js";import"./fetch.223a1647.js";import"./PhPencil.vue.19daefd9.js";import"./SaveButton.5c48e103.js";import"./UnsavedChangesHandler.e1b03d07.js";import"./ExclamationCircleOutlined.8d6633b2.js";import"./CrudView.87635648.js";import"./router.25b634fb.js";import"./Badge.d34a57fa.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.92667220.js";import"./BookOutlined.cfbaf67d.js";import"./PhDotsThreeVertical.vue.05e420b9.js";import"./index.dcf24033.js";import"./index.40a20e0a.js";import"./polling.fe90557c.js";import"./index.19726194.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="0b36b013-ea53-4594-b199-0df77a6f7da5",o._sentryDebugIdIdentifier="sentry-dbid-0b36b013-ea53-4594-b199-0df77a6f7da5")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,c)=>(p(),n(d,null,{default:m(()=>[a(u,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.49717b55.js.map
