import{d as n,o as s,Y as d,a,$ as r,ei as l,a0 as _}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d77e3011-7f49-4853-b701-79d45bcafdf2",e._sentryDebugIdIdentifier="sentry-dbid-d77e3011-7f49-4853-b701-79d45bcafdf2")}catch{}})();const f={class:"content-layout"},c=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",f,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(c,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.d08fae26.js.map
