import{U as c,dA as i,dB as d}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="54f7b642-296e-4518-a083-c42f56f1a74a",e._sentryDebugIdIdentifier="sentry-dbid-54f7b642-296e-4518-a083-c42f56f1a74a")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),y=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{y as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.47d71656.js.map
