.container[data-v-e4dbb5dc]{display:flex;justify-content:center;align-items:center;height:100vh;width:100vw;top:0;left:0;position:fixed;z-index:2;padding-bottom:80px}.container .modal[data-v-e4dbb5dc]{width:750px;height:475px;background-color:#fff;border-radius:10px;border:1px solid #f0f0f0;box-shadow:#00000059 0 5px 15px;display:flex;flex-direction:column}.container .modal .upper[data-v-e4dbb5dc]{padding:8px;border-bottom:1px solid #f0f0f0}.container .modal .content[data-v-e4dbb5dc]{flex:1;flex-direction:column;overflow-y:auto;padding:18px;text-align:left}.container .modal .content .empty-container[data-v-e4dbb5dc]{height:100%}.container .modal .content .entry[data-v-e4dbb5dc]{padding-top:4px;padding-bottom:12px}.container .modal .content .entry .entry-owner[data-v-e4dbb5dc]{display:flex;gap:4px;align-items:center;margin-bottom:4px}.container .modal .lower[data-v-e4dbb5dc]{width:100%;height:40px;margin-top:auto;border-top:1px solid #f0f0f0;padding:0 12px}.container .modal .lower .close-button[data-v-e4dbb5dc]{display:flex;gap:8px;padding:4px 8px}
