import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.45ff4ef7.js";import{L as c}from"./tasksController.17d2b6da.js";import{d as f,e as u,o as _,c as m,w as t,b as s,u as o,dd as y,aG as i,bT as b,dh as k,a0 as w}from"./index.97914b50.js";import{C as T}from"./ContentLayout.d08fae26.js";import{a as g}from"./ant-design.6c73842d.js";import"./metadata.626e405f.js";import"./PhRobot.vue.9e5bcd4c.js";import"./PhWebhooksLogo.vue.c83b69f4.js";import"./string.8b027234.js";import"./dayjs.47d71656.js";import"./index.dcf24033.js";import"./gateway.f03e4b27.js";import"./popupNotifcation.f5d6fec9.js";import"./linters.188b2aea.js";import"./asyncComputed.d84da1aa.js";import"./scripts.1d59675c.js";import"./record.a76b6b89.js";import"./polling.fe90557c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="13d7df03-d18e-4ba2-a0c9-2bb32df5370a",e._sentryDebugIdIdentifier="sentry-dbid-13d7df03-d18e-4ba2-a0c9-2bb32df5370a")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new c,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(d,n)=>(_(),m(T,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.3bdf1ac8.js.map
