import"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1236a515-69ae-4fc4-b9af-e7ee0b935513",e._sentryDebugIdIdentifier="sentry-dbid-1236a515-69ae-4fc4-b9af-e7ee0b935513")}catch{}})();function d(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{d as g};
//# sourceMappingURL=datetime.ec9a0fb5.js.map
