import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.45ff4ef7.js";import{R as f}from"./tasksController.17d2b6da.js";import{d as b,ec as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.97914b50.js";import"./gateway.f03e4b27.js";import{a as j,B as x}from"./build.a54d4bf7.js";import{a as C}from"./project.ab926412.js";import"./tables.ef28572a.js";import{a as D}from"./asyncComputed.d84da1aa.js";import"./metadata.626e405f.js";import"./PhRobot.vue.9e5bcd4c.js";import"./PhWebhooksLogo.vue.c83b69f4.js";import"./ant-design.6c73842d.js";import"./string.8b027234.js";import"./dayjs.47d71656.js";import"./index.dcf24033.js";import"./linters.188b2aea.js";import"./scripts.1d59675c.js";import"./record.a76b6b89.js";import"./polling.fe90557c.js";import"./popupNotifcation.f5d6fec9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ef05b345-a303-425a-905a-470bf902f9ed",e._sentryDebugIdIdentifier="sentry-dbid-ef05b345-a303-425a-905a-470bf902f9ed")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.6e314270.js.map
