import{d as c,em as d,f as r,o,Y as t,S as i,ei as p,ea as u,a0 as _}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="683ae50c-e23e-4aa1-9f5c-6ac1eaa1b966",e._sentryDebugIdIdentifier="sentry-dbid-683ae50c-e23e-4aa1-9f5c-6ac1eaa1b966")}catch{}})();const g={class:"logo"},f=["src","alt"],m=c({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;d(s=>({"4521d904":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),l=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",g,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:l.value},null,8,f)):i("",!0),s.hideText?i("",!0):(o(),t("span",{key:1,class:p(s.size)},u(s.brandName),3))]))}});const h=_(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.6a7a7f34.js.map
