import{L as n}from"./Logo.6a7a7f34.js";import{d as a,o as r,c as d,u as i}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="048442d0-bcee-4c13-9f3e-5abbc0436f96",e._sentryDebugIdIdentifier="sentry-dbid-048442d0-bcee-4c13-9f3e-5abbc0436f96")}catch{}})();const f="/assets/logo.0faadfa2.svg",l=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(n,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.95adbf15.js.map
