import{B as d}from"./BookOutlined.cfbaf67d.js";import{d as c,o as s,c as b,w as o,b as l,u as n,$ as f,Y as u,aG as i,aS as p,bT as y}from"./index.97914b50.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="c9b12d2c-bb65-4116-9416-4aabbaa94a32",t._sentryDebugIdIdentifier="sentry-dbid-c9b12d2c-bb65-4116-9416-4aabbaa94a32")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),b(n(y),{class:"docs-button",href:`https://abstra.io/docs/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?f(e.$slots,"default",{key:0}):(s(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.92667220.js.map
