import{k as n,T as a,m as r,P as o,C as p,M as d,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.97914b50.js";import{s as b,c as y,a as i}from"./workspaceStore.6144f2aa.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.38c5e572.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";import"./PlayerConfigProvider.ae4f9c66.js";import"./index.395a3cd6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f0c410a8-4b43-4474-9202-1b0298e40545",t._sentryDebugIdIdentifier="sentry-dbid-f0c410a8-4b43-4474-9202-1b0298e40545")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=n({render:()=>f(l)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",d),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.455ad571.js.map
