import"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f3e3ff08-142f-4ea7-92e4-f5c1c1ec5038",e._sentryDebugIdIdentifier="sentry-dbid-f3e3ff08-142f-4ea7-92e4-f5c1c1ec5038")}catch{}})();const i=1e3,d=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var o;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(o=e.interval)!=null?o:i)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{d as u};
//# sourceMappingURL=polling.fe90557c.js.map
