import{O as r}from"./workspaceStore.6144f2aa.js";import{d as l,X as i,o as u,Y as c,b as a,w as o,u as n,aG as d,dd as f,dc as b}from"./index.97914b50.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4076bf19-dc3a-497c-98e1-b2adf989194b",e._sentryDebugIdIdentifier="sentry-dbid-4076bf19-dc3a-497c-98e1-b2adf989194b")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.5be801ae.js.map
