import{b as d,ee as c,eK as o}from"./index.97914b50.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f6de4ef9-8240-4d94-9b98-b7d8093042d4",e._sentryDebugIdIdentifier="sentry-dbid-f6de4ef9-8240-4d94-9b98-b7d8093042d4")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){f(e,i,n[i])})}return e}function f(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=l({},t,n.attrs);return d(c,l({},r,{icon:o}),null)};a.displayName="ExclamationCircleOutlined";a.inheritAttrs=!1;const s=a;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.8d6633b2.js.map
