import{P as f}from"./PlayerNavbar.ccade3e3.js";import{d as g,eF as h,ec as c,e as y,f as b,r as k,o as i,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.97914b50.js";import{u as V}from"./workspaceStore.6144f2aa.js";import"./metadata.626e405f.js";import"./PhRobot.vue.9e5bcd4c.js";import"./PhWebhooksLogo.vue.c83b69f4.js";import"./LoadingOutlined.8561fed3.js";import"./PhSignOut.vue.270e1c2a.js";import"./index.d1c53460.js";import"./Avatar.cdeaa917.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="678e01bd-2367-48af-a932-730c180ca462",o._sentryDebugIdIdentifier="sentry-dbid-678e01bd-2367-48af-a932-730c180ca462")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,a=y(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.0c2c8c02.js.map
