import{O as r}from"./workspaceStore.6144f2aa.js";import{d as i,X as l,o as u,Y as c,b as a,w as n,u as o,aG as s,dd as f,dc as b}from"./index.97914b50.js";import"./url.9121ac6e.js";import"./colorHelpers.7fae6e3b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3b45e64a-c842-4333-a4e8-544d909f8fbe",e._sentryDebugIdIdentifier="sentry-dbid-3b45e64a-c842-4333-a4e8-544d909f8fbe")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,d)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.3165321b.js.map
