import{d as b,eF as f,ec as m,o as c,c as p,w as l,u as n,Y as _,e9 as g,b as y,a as v,ea as w,aS as k}from"./index.97914b50.js";import{A as I,T}from"./TabPane.0573791a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="369651e2-4ef7-434b-929c-aff4c2fcab15",e._sentryDebugIdIdentifier="sentry-dbid-369651e2-4ef7-434b-929c-aff4c2fcab15")}catch{}})();const B=b({__name:"TablesTabs",setup(e){const a=f(),t=m(),u=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(c(),p(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:l(()=>[(c(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:l(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.29e2063b.js.map
